@@ -31,6 +31,7 @@ import (
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/apex/log"
 	"github.com/blacktop/ipsw/internal/utils"
+	"github.com/blacktop/ipsw/pkg/dyld"
 	"github.com/blacktop/ipsw/pkg/kernelcache"
 	"github.com/blacktop/ipsw/pkg/ota"
 	"github.com/fatih/color"
@@ -80,56 +81,78 @@ var otaExtractCmd = &cobra.Command{
 			return fmt.Errorf("cannot use both FILENAME and flag for --pattern")
 		}
 
-		o, err := ota.Open(filepath.Clean(args[0]))
+		o, err := ota.Open(filepath.Clean(args[0]), viper.GetString("ota.key-val"))
 		if err != nil {
 			return fmt.Errorf("failed to open OTA file: %v", err)
 		}
 
-		output := filepath.Dir(filepath.Clean(args[0]))
-		if viper.IsSet("ota.extract.output") {
-			output = filepath.Clean(viper.GetString("ota.extract.output"))
+		info, err := o.Info()
+		if err != nil {
+			return fmt.Errorf("failed to get OTA info: %v", err)
+		}
+		output, err := info.GetFolder()
+		if err != nil {
+			return fmt.Errorf("failed to get OTA folder: %v", err)
 		}
 
-		/* DYLD_SHARED_CACHE */
-		if viper.GetBool("ota.extract.dyld") {
-			log.Info("Extracting dyld_shared_cache Files")
-			return fmt.Errorf("--dyld extraction not implemented yet")
+		if viper.IsSet("ota.extract.output") {
+			output = filepath.Join(viper.GetString("ota.extract.output"), output)
 		}
-		/* KERNELCACHE */
-		if viper.GetBool("ota.extract.kernel") {
-			re := regexp.MustCompile(`kernelcache.*$`)
-			for _, f := range o.Files() { // search in OTA asset files
-				if f.IsDir() {
-					continue
+
+		if viper.GetBool("ota.extract.dyld") || viper.GetBool("ota.extract.kernel") {
+			cwd, _ := os.Getwd()
+			/* DYLD_SHARED_CACHE */
+			if viper.GetBool("ota.extract.dyld") {
+				log.Info("Extracting dyld_shared_cache Files")
+				out, err := o.ExtractFromCryptexes(dyld.CacheUberRegex, output)
+				if err != nil {
+					return fmt.Errorf("failed to extract dyld_shared_cache: %v", err)
 				}
-				if re.MatchString(f.Path()) {
-					ff, err := o.Open(f.Path(), false)
-					if err != nil {
-						return fmt.Errorf("failed to open file '%s' in OTA: %v", f.Path(), err)
+				for _, fname := range out {
+					rel, _ := filepath.Rel(cwd, fname)
+					utils.Indent(log.Info, 2)(rel)
+				}
+			}
+			/* KERNELCACHE */
+			if viper.GetBool("ota.extract.kernel") {
+				log.Info("Extracting kernelcache(s)")
+				re := regexp.MustCompile(`kernelcache.*$`)
+				for _, f := range o.Files() { // search in OTA asset files
+					if f.IsDir() {
+						continue
 					}
-					data, err := io.ReadAll(ff)
-					if err != nil {
-						return fmt.Errorf("failed to read kernelcache: %v", err)
-					}
-					comp, err := kernelcache.ParseImg4Data(data)
-					if err != nil {
-						return fmt.Errorf("failed to parse kernelcache: %v", err)
-					}
-					kdata, err := kernelcache.DecompressData(comp)
-					if err != nil {
-						return fmt.Errorf("failed to parse kernelcache compressed data: %v", err)
-					}
-					fname := filepath.Join(output, f.Name())
-					if err := os.MkdirAll(filepath.Dir(fname), 0o750); err != nil {
-						return fmt.Errorf("failed to create output directory: %v", err)
-					}
-					utils.Indent(log.Info, 2)(fname)
-					if err := os.WriteFile(fname, kdata, 0o644); err != nil {
-						return fmt.Errorf("failed to write kernelcache: %v", err)
+					if re.MatchString(f.Path()) {
+						ff, err := o.Open(f.Path(), false)
+						if err != nil {
+							return fmt.Errorf("failed to open file '%s' in OTA: %v", f.Path(), err)
+						}
+						data, err := io.ReadAll(ff)
+						if err != nil {
+							return fmt.Errorf("failed to read kernelcache: %v", err)
+						}
+						comp, err := kernelcache.ParseImg4Data(data)
+						if err != nil {
+							return fmt.Errorf("failed to parse kernelcache: %v", err)
+						}
+						kdata, err := kernelcache.DecompressData(comp)
+						if err != nil {
+							return fmt.Errorf("failed to parse kernelcache compressed data: %v", err)
+						}
+						fname := filepath.Join(output, f.Name())
+						if err := os.MkdirAll(filepath.Dir(fname), 0o750); err != nil {
+							return fmt.Errorf("failed to create output directory: %v", err)
+						}
+						rel, _ := filepath.Rel(cwd, fname)
+						utils.Indent(log.Info, 2)(rel)
+						if err := os.WriteFile(fname, kdata, 0o644); err != nil {
+							return fmt.Errorf("failed to write kernelcache: %v", err)
+						}
 					}
 				}
 			}
+			return nil
 		}
+
 		/* ALL FILES */
 		if len(args) == 1 && !viper.IsSet("ota.extract.pattern") {
 			log.Info("Extracting All Files From OTA")
@@ -230,7 +253,10 @@ var otaExtractCmd = &cobra.Command{
 				}
 				if cont {
 					utils.Indent(log.Info, 2)(fmt.Sprintf("Searching for '%s' in OTA payload files", re.String()))
-					return o.GetPayloadFiles(viper.GetString("ota.extract.pattern"), viper.GetString("ota.extract.range"), output)
+					return o.GetPayloadFiles(
+						viper.GetString("ota.extract.pattern"),
+						viper.GetString("ota.extract.range"),
+						output)
 				}
 			}
 		}
